package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$"`0`````````````#``0````!```=@````#0``,$4```````T`"``
M"0`H`!D`&`````8````T````-````#0```$@```!(`````0````$`````P``
M`7@```%X```!>`````T````-````!`````$````!``````````````````"Q
M%```L10````%```@``````$``+R0``#<D```W)````.(```#G`````8``"``
M`````@``O)@``-R8``#<F````0@```$(````!@````0````$```!5````50`
M``%4````)````"0````$````!`````0``+#T``"P]```L/0````@````(```
M``0````$9'3E40``````````````````````````````!@```!!D=.52``"\
MD```W)```-R0```#<````W`````$`````0````0````4`````T=.50!`.P5H
M(09\M9##?611%Y10AA443B]L:6(O;&0N<V\N,0`````````1````2`````@`
M```(!!`0`(`$0"4$```HA`"&H`(`@8`(!"@+01*`.`@``(H`````````2```
M`$L```!.````3P```%<```!8````60````````!;````7````%T```!>````
M7P```&$``````````!_?Q6XM1][.?)I_:[:;Q2Y\U&34#N3_(1Q8<=D!QD?B
M;XL!LL#C2ZR'U_I"+#_EPGR2X[I@;*'ZF\-/F=9#"6MFS*]G[-5%0M-P!XGM
MVV(SS"6,%0N7.@V;G*E_"@*GX%">&FM)^^"C````````````````````````
M`````!80``````,```H```+M```````````2```````"*```````````$@``
M`````A,``````````!(```````#D```````````2````````E@``````````
M$@```````5T``````````!(```````'<```````````2```````"7P``````
M````$@```````/H``````````!(````````!```````````@```````"20``
M````````$@```````KL``````````!(```````,0```````````2```````"
M+P``````````$@```````2L``````````!(```````$;```````````2````
M```"P@``````````$@```````0T``````````!(```````'C```````````2
M```````"#@``````````$@```````!```````````"````````%[````````
M```2````````Z0``````````$@```````M@``````````!(````````L````
M```````@```````"&0``````````$@```````LD``````````!(```````!&
M```````````2````````8P``````````%@```````4T``````````!(`````
M``!V```````````2````````TP``````````$@```````(<``````````!(`
M``````'"```````````2```````"G@``````````$0```````M\`````````
M`!(```````(!```````````2```````!ZP``````````$@```````^``````
M`````!(```````"W```````````2```````#(@``````````$0```````M$`
M`````````!(```````,(```````````1```````!TP``````````$@``````
M`3\``````````!(```````*.```````````2```````!=```````````$@``
M`````.X``````````!(```````&D```````````2```````""```````````
M$@```````?H``````````!(```````)````````````2```````!\@``````
M````$@```````*(``````````!(```````%H```````````2```````";0``
M````````$@```````E$``````````!(```````,&```````````1```````"
MI0``````````$@```````OX``````````!(```````#&```````````1````
M```!A@``````````$0```````30``````````!(```````!4```````````2
M```````!S```````````$@```````GP``````````!(```````&Z````````
M```2```````"Y@``````````$@```````JP``````````"(```````&U````
M```````2```````#Z0``-[0```#&$@``#```!"\``"Z<```&;!(```P```*)
M```;$````FX2```,```#=@``)1P````&$@``#````U8``#4(```"K!(```P`
M``15```E(@```=H2```,```$%0``X!@`````$```%@```X<``";\````*!(`
M``P```.4```KX@```&(2```,```!E0``<)(````$$0``#@``!`(``&Q<```!
M7!(```P```0-```D+````$`2```,```$*@``X"P`````$```%@``!$,``"W@
M````O!(```P```1B```L1````#02```,```#]0``X```````$```%0```[@`
M`"<D````SA(```P```0\``#@&``````0```5```#;```X!(````$$0``%0``
M`_L``!V``````!(```P```0A``!K_@```%X2```,```#]P``X```````(```
M%0```\X``"W&````&A(```P```.B```D;````+`2```,```#Q```;;@```*4
M$@``#```!&H``"?R```#\!(```P`7U]G;6]N7W-T87)T7U\`7TE435]D97)E
M9VES=&5R5$U#;&]N951A8FQE`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`
M4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!03%]C=7)R96YT7V-O;G1E
M>'0`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S
M=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7W-V7W-E='!V;@!03%]D;U]U
M;F1U;7``4&5R;%]N97=84U]F;&%G<P!P97)L7V9R964`4&5R;%]M9U]S970`
M4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C
M:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!B;V]T7T1Y
M;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A
M;&QO8P!03%]M96UO<GE?=W)A<`!?24]?<W1D:6Y?=7-E9`!?7W-T86-K7V-H
M:U]F86EL`&5X:70`;'-E96LV-`!R96%D9&ER-C0`<W1R9'5P`&-L;W-E9&ER
M`&]P96XV-`!S=')R8VAR`'5N;&EN:P!M96UM;W9E`'-T<G1O:P!S=')L96X`
M<FUD:7(`<F5A9`!M:V1I<@!?7W9F<')I;G1F7V-H:P!G971P:60`7U]L<W1A
M=#8T7W1I;64V-`!R96%D;&EN:P!R96%L;&]C`%]?<W!R:6YT9E]C:&L`7U]F
M<')I;G1F7V-H:P!?7VTV.&M?<F5A9%]T<`!?7VQI8F-?<W1A<G1?;6%I;@!?
M7W-T870V-%]T:6UE-C0`<W1D97)R`&UE;6-H<@!?7V-X85]F:6YA;&EZ90!S
M=')C:'(`;65M<V5T`&]P96YD:7(`9V5T=6ED`&%C8V5S<P!M96UC<'D`<W1R
M8VUP`%]?97)R;F]?;&]C871I;VX`<W1R;F-M<`!?7V5N=FER;VX`7U]R96=I
M<W1E<E]A=&9O<FL`7U]S=&%C:U]C:&M?9W5A<F0`;&EB<&5R;"YS;RXU+C0P
M`&QI8F,N<V\N-@!L9"YS;RXQ`%A37TEN=&5R;F%L<U]005)?0D]/5`!M>5]P
M87)?<&P`<&%R7V-U<G)E;G1?97AE8P!P87)?8F%S96YA;64`<&%R7V5N=E]C
M;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA;64`<VAA7V9I
M;F%L`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%]?
M9&%T85]S=&%R=`!S:&%?=7!D871E`'AS7VEN:70`7U]B<W-?<W1A<G0`<VAA
M7VEN:70`7V5N9`!P87)?;6MT;7!D:7(`7V5D871A`'!A<E]S971U<%]L:6)P
M871H`'!A<E]F:6YD<')O9P!P87)?9&EE`'!A<E]I;FET7V5N=@!'3$E"0U\R
M+C0`1TQ)0D-?,BXQ+C,`1TQ)0D-?,BXQ,@!'3$E"0U\R+C(`1TQ)0D-?,BXS
M-`!'3$E"0U\R+C,N,@!'3$E"0U\R+C,N-`!'3$E"0U\R+C$`1TQ)0D-?,BXP
M``````````(``@`"``$``0`!``,`!``!``$``@`"``4`!@`!``$``@`!``(`
M`@`!``$``@`"``$`!``"``$``0`!``$``0`!``<``@`"``(``@`"``$`"``"
M``(``@`!``8``@`!``D``@`"``(``@`!``$`"@`$``(``@`"``$``0`!``$`
M`@`&``,``@`+``(``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!`````0`!```#3@```!`````@#6EI%`````@`
M``1W```````!``D```-$````$``````):1]S````"P``!($````0!I:1D@``
M``H```2-````$`UI:10````)```$=P```!`-:6D2````!P``!)@````0!I:1
MM`````8```2B````$`EI&7(````%```$K0```!`):1ET````!```!+D````0
M#6EI$0````,```3%````$`UI:1`````"```$SP```````-R0````%@``'FP`
M`-R4````%@``'B@``-ZD````%@``&Q```-ZL````%@``X!@``-Z\````%@``
MX`0``-[,````%@``-0@``-[<````%@``<)8``-[@````%@``X!(``-[H````
M%@``X!P``-[L````%@``<)P``-[P````%@``<*L``-[T````%@``<V@``-[X
M````%@``<,<``-[\````%@``(\```-\`````%@``L.8``-\$````%@``<*<`
M`-\(````%@``<-P``-\,````%@``<.@``-\0````%@``<.H``-\4````%@``
M</,``-\8````%@``<0```-\<````%@``<0(``-\@````%@``<@L``-\D````
M%@``<00``-\H````%@``<0T``-\L````%@``<14``-\P````%@``<1X``-\T
M````%@``<24``-\X````%@``<34``-\\````%@``<4$``-]`````%@``<4L`
M`-]$````%@``<54``-](````%@``<5\``-],````%@``<7```-]0````%@``
M<8(``-]4````%@``<8T``-]8````%@``<9T``-]<````%@``<:X``-]@````
M%@``<;```-]D````%@``<;T``-]H````%@``X`@``-]L````%@``<<D``-]P
M````%@``<=D``-]T````%@``<>```-]X````%@``<7L``-]\````%@``<>4`
M`-^`````%@``<9@``-^$````%@``<>T``-^(````%@``<?$``-^,````%@``
M<?8``-^0````%@``<?\``-^4````%@``<@0``-^8````%@``<@D``-^<````
M%@``<A(``-^@````%@``<DT``-^D````%@``<=0``-^H````%@``<J```-^L
M````%@``<J4``-^P````%@``<JH``-^T````%@``<K4``-^X````%@``<L0`
M`-^\````%@``<M(``-_`````%@``<N,``-_$````%@``<N4``-_(````%@``
M<NH``-_,````%@``<NP``-_0````%@``<P$``-_4````%@``<P<``-_8````
M%@``<R@``-_<````%@``X"```-_@````%@``X"0``-_D````%@``<.4``-_H
M````%@``<VD``-_L````%@``<VP``-_P````%@``X"@``-_X````%@``X!@`
M`-_\````%@``X!@``.`$````%@``X`0``.`2````%@``<V\``-Z@```>*@``
M`````-ZH```+%````````-ZP```6%````````-ZT```:%````````-ZX``!&
M%````````-[````L%````````-[$```J%````````-[(```?%````````-[0
M```D%````````-[4```*%````````-[8```@%````````-[D```_%```````
M`-_T```^%````````-VL```"%0```````-VP```#%0```````-VT```$%0``
M`````-VX```%%0```````-V\```&%0```````-W````'%0```````-W$```(
M%0```````-W(```)%0```````-W,```*%0```````-W0```+%0```````-W4
M```,%0```````-W8```-%0```````-W<```.%0```````-W@```/%0``````
M`-WD```0%0```````-WH```1%0```````-WL```2%0```````-WP```3%0``
M`````-WT```4%0```````-WX```5%0```````-W\```7%0```````-X````8
M%0```````-X$```9%0```````-X(```;%0```````-X,```<%0```````-X0
M```=%0```````-X4```?%0```````-X8```@%0```````-X<```A%0``````
M`-X@```B%0```````-XD```C%0```````-XH```E%0```````-XL```F%0``
M`````-XP```G%0```````-XT```H%0```````-XX```I%0```````-X\```K
M%0```````-Y````M%0```````-Y$```N%0```````-Y(```O%0```````-Y,
M```P%0```````-Y0```Q%0```````-Y4```R%0```````-Y8```S%0``````
M`-Y<```T%0```````-Y@```U%0```````-YD```V%0```````-YH```W%0``
M`````-YL```X%0```````-YP```Y%0```````-YT```Z%0```````-YX```\
M%0```````-Y\```]%0```````-Z```!`%0```````-Z$``!!%0```````-Z(
M``!"%0```````-Z,``!#%0```````-Z0``!$%0```````-Z4``!%%0``````
M`-Z8``!&%0```````-Z<``!'%0````!.5@``+PU+^P%P``#'B$JU`7````$(
M9P9A_P```-8J;O_\3EY.=0``+SL!<```QVI.^P%Q``#'9@````!.^P%Q``#'
M7B\\`````&#_____W$[[`7$``,=.+SP````,8/_____(3OL!<0``QSXO/```
M`!A@_____[1.^P%Q``#'+B\\````)&#_____H$[[`7$``,<>+SP````P8/__
M__^,3OL!<0``QPXO/````#Q@_____WA.^P%Q``#&_B\\````2&#_____9$[[
M`7$``,;N+SP```!48/____]03OL!<0``QMXO/````&!@_____SQ.^P%Q``#&
MSB\\````;&#_____*$[[`7$``,:^+SP```!X8/____\43OL!<0``QJXO/```
M`(1@_____P!.^P%Q``#&GB\\````D&#____^[$[[`7$``,:.+SP```"<8/__
M__[83OL!<0``QGXO/````*A@_____L1.^P%Q``#&;B\\````M&#____^L$[[
M`7$``,9>+SP```#`8/____Z<3OL!<0``QDXO/````,Q@_____HA.^P%Q``#&
M/B\\````V&#____^=$[[`7$``,8N+SP```#D8/____Y@3OL!<0``QAXO/```
M`/!@_____DQ.^P%Q``#&#B\\````_&#____^.$[[`7$``,7^+SP```$(8/__
M__XD3OL!<0``Q>XO/````11@_____A!.^P%Q``#%WB\\```!(&#____]_$[[
M`7$``,7.+SP```$L8/____WH3OL!<0``Q;XO/````3A@_____=1.^P%Q``#%
MKB\\```!1&#____]P$[[`7$``,6>+SP```%08/____VL3OL!<0``Q8XO/```
M`5Q@_____9A.^P%Q``#%?B\\```!:&#____]A$[[`7$``,5N+SP```%T8/__
M__UP3OL!<0``Q5XO/````8!@_____5Q.^P%Q``#%3B\\```!C&#____]2$[[
M`7$``,4^+SP```&88/____TT3OL!<0``Q2XO/````:1@_____2!.^P%Q``#%
M'B\\```!L&#____]#$[[`7$``,4.+SP```&\8/____SX3OL!<0``Q/XO/```
M`<A@_____.1.^P%Q``#$[B\\```!U&#____\T$[[`7$``,3>+SP```'@8/__
M__R\3OL!<0``Q,XO/````>Q@_____*A.^P%Q``#$OB\\```!^&#____\E$[[
M`7$``,2N+SP```($8/____R`3OL!<0``Q)XO/````A!@_____&Q.^P%Q``#$
MCB\\```"'&#____\6$[[`7$``,1^+SP```(H8/____Q$3OL!<0``Q&XO/```
M`C1@_____#!.^P%Q``#$7B\\```"0&#____\'$[[`7$``,1.+SP```),8/__
M__P(3OL!<0``Q#XO/````EA@____^_1.^P%Q``#$+B\\```"9&#____[X$[[
M`7$``,0>+SP```)P8/____O,3OL!<0``Q`XO/````GQ@____^[A.^P%Q``##
M_B\\```"B&#____[I$[[`7$``,/N+SP```*48/____N03OL!<0``P]XO/```
M`J!@____^WQ.^P%Q``##SB\\```"K&#____[:$[[`7$``,.^+SP```*X8/__
M__M43OL!<0``PZXO/````L1@____^T!.^P%Q``##GB\\```"T&#____[+$Y6
M__!(YS`\2_L!<```PH8M;@`,__0M;@`0__`F=0%P```!)"U3__Q(;O_P2&[_
M]$AN``AA_____SX@-0%P```!-"\`+P`O-0%P```!.&'_``!4["!U`7````)4
M3^\`&$H09P`!"&'____^J-'U`7````$`(%``*``#`T0D+@`(5H(@+@`(6(`,
M@#____]B``&&Y8@O`&'____^9")U`7````)`(H@H;O_T()0A=0%P```"2``$
M(G4!<````4`A40`((74!<````DP`#"(N``A8CW`!L(%L``%40^P`!$7H`!`@
M`>6(T(PDV;/`9OI6@4*P'`!"IR\(+P(O-0%P```!7"1U`7````)0+Q)A____
M^I)/[P`42H!G``"(+Q)A_____10D`"8.48,O`R\U`7````&88?\```(N3^\`
M#$J(9P``DB\28?____HP8?____OB6(\B+O_\(!.P@68``0H@`DSN/`S_V$Y>
M3G5A____^UXB=0%P```"4"*(9P``X"\(8?____O\8?____V&T?4!<````0`@
M4$(H!>98CV``_L8O$F'____ZKEB/+Q)A_____(0D`"8.48,O`R\U`7````&8
M8?\```&>3^\`#$J(9@#_<BAU`7````(\(%1*B&<.+PAA_P``&KY8CV``_U8O
M`R\U`7````%P8?\```%H*(A0CV<`_SXO"&'_```:F%B/8`#_,"\U`7````%$
M+S4!<````D1A_____,!R!$*P'`!"IR\(+P(O-0%P```!7"1U`7````)0+Q)A
M____^51/[P`42H!F`/[$8`#_1DAX``%A_____8AA_____!I.<9W.(!\@3TA7
M2%%"IT*G2_L!<```P!!(4"\`+S4!<````01A_____0A*_$YQ+PU+^P%P``"_
M\"`U`7````$,(C4!<````ERR@&<2('4!<````1!*B&<&+P%.D%B/*E].=2\-
M+P)+^P%P``"_NB`U`7````$,(C4!<````ER0@20`Y(+0@)&`1(#0@N*`9Q0@
M=0%P```!%$J(9P@O`"\!3I!0CR0?*E].=2\-+PI+^P%P``"_<B1U`7````)8
M2A)F)DJU`7````$89Q(@=0%P```!'"\08?____R26(]A_____TX4O``!)%\J
M7TYU8/____]R3G%(YR`^2_L!<```OR8H;P`<2HQG>"!U`7````$@+%!*CF=J
M$!0@3$*"2@!G$`P``#UG!E*($!!F]"0(E(PD5DJ*9R8F3B\"+PPO"F'____[
MG$_O``Q*@&8(##(`/2@`9Q)8BR132HIFW"!*(`I,WWP$3G67SB`+Y(`@;P`@
M((!%\B@!($H@"DS??`1.=97*($H@"DS??`1.=4Y6_Y!(YR`D2_L!<```OHHD
M+@`()'4!<````20M4O_\2&[_D"\"8?____@<4(]*@&8N(B[_H`*!``#P``R!
M``!``&<@#($``*``9Q@@;O_\(A*RB&8F3.XD!/^$3EY.=4*`8.A(>``"+P)A
M____^(Q0CTJ`5\!)P$2`8-!A____^@I.5O^,2.<P/$O[`7```+X()FX`""AU
M`7````$D+53__$J+9P1*$V86(B[__"`4L(%F``%P3.X\#/]T3EY.=2\+8?__
M__A<)`A8CV?<+P)A____^,98CTJ(9P``G$7H`!,,$@`N9P``IB\+8?____C2
M+4#_C"Z*8?____C&6(\@;O^,2'`(`F'____Y5B8(+PHO"R\U`7````$\2'C_
M_TAX``$O"&'____Z`$AN_Y`O`V'____Y&$_O`"12@&<4("[_H`*```#P``R`
M``!``&<``+HO`V'____X?%B/+P-A____]X)8CR\"8?____@L6(]*B&8`_V@O
M`F'____XJ"\+8?____D84(]@`/\>2BH``6<`_SH,$@`N9@#_3@PJ`"X``68`
M_T1**@`"9P#_("\+8?____@,+4#_C"Z*8?____@`6(\@;O^,2'`(`F'____X
MD"8(+PHO"R\U`7````$\2'C__TAX``$O"&'____Y.DAN_Y`O`V'____X4D_O
M`"12@&<`_TY@`/\V+P-A_____G)8CR\#8?____;*6(]@`/]&8?____AB3E;_
M]$CG/CQ+^P%P``"\8"AN``@D;@`,)C4!<````20@0RU0__P,$@`]9P``M"\*
M8?____=D6(\M0/_T2&[_^"\,8?____SZ)`A0CV<``+8O"&'____W0EB/L*[_
M]&0``/XH+O_XY8PF=0%P```!(!(4($QG``$R#`$`/6<&4H@2$&;TD<PD$]2$
M(F[_]$AQB`)A____]Z(B0B*(6(]G*"!3(G!(`!`<$H!G$"!)4HD,```]9P@0
M'!*`9O`@21#\`#T0&A#`9OHB+O_\($,@$+"!9@``[DSN/'S_T$Y>3G52BB\*
M8?____:P6(\M0/_T2&[_^"\,8?____Q&)`A0CV8`_TXF=0%P```!("H3(D5*
MD6<``)H@14*"6(@@`E*"2I!F]E:`Y8@@=0%P```!2$J09SXO`"\%8?____2D
M+`@FB%"/9X(H`N6,($9"L"P$+4+_^!(4($QF`/\>8$H@0A`:$,!G`/]B$!H0
MP&;R8`#_6'(!(($O`&'____VO"P(6(]G`/]$*`+EC"\$+P4O"&'____W'":&
M3^\`#"!&0K`L!"U"__A@K)'(8`#^VG`(0H(@=0%P```!2$J09[1@`/]T8?__
M__::3^_O_$CG/"1+^P%P``"ZF"@O$"`J+Q`D)'4!<````20O4A`82'@/_W8<
MUH\O`R\U`7````%,8?____::)`!/[P`,;PQ3@$HW*!=F.$J`9C(O!2\$8?__
M__;,T?4!<````0`O$&'____T/$_O``PB+Q`8(!*P@69$3-\D/$_O$`1.=20`
M+P)(>``O+P-A____]KQ/[P`,2HAGMB\"+P,O!&'____V@-'U`7````$`+Q!A
M____]5A/[P`08+)A____]=@O#2\*2_L!<```N=HO-0%P```!8"\U`7````$H
M+S4!<````5!A____]CHD=0%P```!`-7(+Q)A____]GA"IR`U`7````%4+P`O
M`"\U`7````$L+S4!<````5@O$F'____T7D_O`"@D7RI?3G4O#4O[`7```+EP
M+S4!<````6`O-0%P```!*"\U`7````%08?____70T?4!<````0`O$&'____V
M$$_O`!`J7TYU3^_?^$CG(#Q+^P%P``"Y*BAU`7````$D+U0@&&'____QUB\U
M`7````%D+P`O-0%P```!:$AX$`%(>``!1>\`*B\*8?____6$2'@0`"0/!H(`
M`!`S+P(O"F'____U"B1`3^\`)$J`;3Y(:@`!8?____22)DA8CTJ(9Q0O"B\"
M+PAA____\\I",Z@`3^\`#"(O(!@@%+"!9A(@2R`+3-\\!$_O(`A.=9?+8.1A
M____]'Q@_____TY/[^^02.<_/DO[`7```+AT)"\0H"8O$*0H=0%P```!)"]4
M$)AZ+-J/+P4O-0%P```!<&'____Y'B9(2'@`+R\"8?____'$3^\`$$J(9RPO
M`B\U`7````%T8?____NZ4(\@0B(O$)@@%+"!9@`!:"`(3-]\_$_O$'!.=2\#
M8?____3X)C4!<````7@O`R\(8?____0*)$A/[P`,2HAGL"XU`7````%\+#4!
M<````8`H#P:$````F$H29P``LDJ+9Q(O"B\+8?____3L4(]*@&<``((O"F'_
M___RU%B/+$!#\@C_L\IC&@P1`"]F"$(14XFSRF;R+PIA____\K)8CRQ`+P)A
M____\J98CT'V"`&P_`__8@#_.B\"+P<O"B\&2'@0`$AX``$O!&'____SZ"\%
M+P1A____\P)/[P`D2H!F$B`O`#P"@```\``,@```@`!G-"\#0J=A____\T(D
M2%"/2HAG`/[J2A)F`/]22HMG!@P3`"YG0CQ\``$D=0%P```!;&``_WQ(>``!
M+P1A____\510CTJ`9KHO!"\U`7````%T8?____IP+P1A____\\I/[P`,8`#^
MK$HK``%FN"\#0J=A____\M8D2%"/2HAFEF``_GQA____\IPO`B0O``A(>``O
M+P)A____\*I0CTJ(9P0D"%*"+T(`""0?8/____-X3^_O_$CG(#Q+^P%P``"V
M<B9O$!PH=0%P```!)"]4$!1*BV=^2A-G>B\+8?____%\6(\D`%*`#(```!``
M8@``AD7O`!0O`"\++PIA____\4A!\BC_3^\`#+7(9`X,$``O9@A"$%.(M<AF
M\DAX`"\O"F'____P'E"/2HAG)K7(9`)"$"\*8?____+N6(\B+Q`4(!2P@68R
M(`A,WSP$3^\0!$YU(B\0%"`4L(%F'"]U`7````%L$!Q,WSP$3^\0!&#____R
MM)'(8,1A____\:91CTCG/S1+^P%P``"UIB9U`7````$D+U,`*'0DU(\F-0%P
M```!A"1U`7````$@+P(O`V'____V3E"/2HAG*"`O`"3EB"!2T<`@*``$((!G
MWEB(("@`!""`9]18B"`H``0@@&;L8,@F-0%P```!B"1U`7````$@+P(O`V'_
M___V!E"/2HAG*"`O`"3EB"!2T<`@*``$((!GWEB(("@`!""`9]18B"`H``0@
M@&;L8,@F-0%P```!C"1U`7````$@+P(O`V'____UOE"/2HAG*"`O`"3EB"!2
MT<`@*``$((!GWEB(("@`!""`9]18B"`H``0@@&;L8,@F-0%P```!D"1U`7``
M``$@+P(O`V'____U=E"/2HAG*"`O`"3EB"!2T<`@*``$((!GWEB(("@`!""`
M9]18B"`H``0@@&;L8,@F-0%P```!E"1U`7````$@+P(O`V'____U+E"/2HAG
M*"`O`"3EB"!2T<`@*``$((!GWEB(("@`!""`9]18B"`H``0@@&;L8,@H-0%P
M```!F"1U`7````$@+P(O!&'____TYE"/2HAG*"`O`"3EB"!2T<`@*``$((!G
MWEB(("@`!""`9]18B"`H``0@@&;L8,@H-0%P```!<"1U`7````$@+P(O!&'_
M___TGE"/2HAG*"`O`"3EB"!2T<`@*``$((!GWEB(("@`!""`9]18B"`H``0@
M@&;L8,@L-0%P```!G"1U`7````$@+P(O!F'____T5E"/2HAG*"`O`"3EB"!2
MT<`@*``$((!GWEB(("@`!""`9]18B"`H``0@@&;L8,@J-0%P```!H"1U`7``
M``$@+P(O!6'____T#E"/2HAG*"`O`"3EB"!2T<`@*``$((!GWEB(("@`!""`
M9]18B"`H``0@@&;L8,@N-0%P```!I"1U`7````$@+P(O!V'____SQE"/2HAG
M*"`O`"3EB"!2T<`@*``$((!GWEB(("@`!""`9]18B"`H``0@@&;L8,@N-0%P
M```!="1U`7````$@+P(O!V'____S?E"/2HAG*"`O`"3EB"!2T<`@*``$((!G
MWEB(("@`!""`9]18B"`H``0@@&;L8,@O`B\U`7````&H8?____-`4(]*B&<,
M+P@O!6'____U\E"/+P(O-0%P```!K&'____S'E"/2HAG$B\(+S4!<````;!A
M____]<I0CR\"+S4!<````;1A____\O90CTJ(9S`O""\$8?____6H4(\O-0%P
M```!O"\#8?____664(\B+P`H(!.P@68L3-\L_%"/3G4O`B\U`7````&X8?__
M__*P4(]*B&?&+P@O!F'____U8E"/8+AA____[;9.5O_X+PTO"DO[`7```+&T
M)'4!<````20M4O_\2&[_^"\U`7````&<8?____)H4(]*B&<D$!!G(`P``#!6
MP$G`1(`@;O_\(A*RB&80)&[_\"IN__1.7DYU0H!@YF'____M5$Y6```O#4O[
M`7```+%42&X`#"\N``A(>``!('4!<````3`O$&'____KKDAX`/]A____[HC?
M_/_^__1(YS\\2_L!<```L1PH-P%P``$`."9U`7````$D+Y,!<``!`#!(>``"
M0J="IR\$8?___^X2=/]V_]:!U8`@`@*`@````"(#`H$``/__3^\`$$J`;0``
MM):!E8!K=DGO`"@D=0%P```!R$*G+P,O`B\$8?___^W03^\`$'K_?/^<@9N`
M9P``L"\\``$`""\,+P1A____ZKA/[P`,?/^\@&<``(9R![*`9!1!]`CXN<AB
M#"H0NI)G.E.(N<AC]'#_!H/__P``U8!Z_WS_1D:<@YN"9I9P_W+_(G<!<``!
M`#`@4[')9EY,WSS\W_P``0`,3G4L*``$O*H`!&:\D<PB"%O`2<#2@]&"8,Y"
MA5.!D85\_T*'+@$`A___``!"@'(!TH?1AF``_S(O-0%P```!Q&'____^EB\U
M`7````'`8?____Z(8?___^O28?___^M4+P!A____ZR18CTJ(9P(@4"`(3G5.
M5O_X2.<X/$O[`7```*^V)BX`""9U`7````$D+5/__$AN__@D-0%P```!S"\"
M8?____!D)$A0CTJ(9P1*$&8@+P,O`F'____S$%"/(B[__"`3L(%F8$SN/!S_
MW$Y>3G4O`V'____JB"A`+HIA____ZGY8CTAT"`)A____ZQ(H""\*+S4!<```
M`7@O`R\U`7````&`2'C__TAX``$O"&'____KM$_O`!PNA"\"8?____*H4(]@
MEF'____J_$_O_RQ(YS\^2_L!<```KOHH;P$$)G4!<````20O4P#\+W4!<```
M`=0`G"]U`7````%L`*!"KP"D+W4!<````=@`N"]U`7````'<`+PO=0%P```!
MX`#`+W4!<````>0`Q$*O`,@O=0%P```!Z`"H+W4!<````>P`K$*O`+!T,-2/
M+P(F-0%P```!<"\#8?___^]*4(]*B&<&2A!F``*:8?___^G@+P!A____Z;!8
MCTJ(9P`!O"102HIG``&T+PIA____Z7!8C]"`4H`O`&'____J`BQ($!)8CR@(
M2@!G+BHU`7````'P`H````#_+P`O!4AX__](>``!+PYA____ZIQ2BE2.$!)/
M[P`49MI-[P"X(#4!<````;`O`B\`8?___^ZZ4(]*B&<&2A!F``$0(!YFYDWO
M`)PD7DJ*9R1*$F<``88O"F'____O*EB/2H!GYB\*8?___^JH)$A8CTJ(9]8O
M"F'____HS"Q`+H1A____Z,)-]@D@!`0L#BZ.8?___^E2+$@O!"\U`7````'T
M*C4!<````7PO!2\*+S4!<````?A(>/__2'@``2\(8?___^GJ3^\`)$AX`<`O
M#F'____F&E"/4H!F$&'____EYB`0<A&R@&8``Q8O`B\.8?___^;6*`!0CV84
M("\`0`*```#P``R```!``&<``6PO#B\4+S4!<````@!(>``!('4!<````3`O
M$&'____F)$_O`!25RB(O`/P@$["!9@`$+"!*(`I,WWS\3^\`U$YU+P@O2``P
M8?___^XL6(\@;P`L2H!G`/[<+PAA____Z:0D2%B/2HAF`/[\3>\`G&``_LI-
M[P"H(!YG*B\"+P!A____[5Q0CTJ(9^Q*$&?H+PAA____Z6XD2%B/2HAF`/XB
M(!YFUDAX``UA____Z"HL2%B/*`@D=0%P```!T'!3*C4!<````?!@`/XBE<HO
M"F'____G9"Q`+H1A____YUI-]@D@!`0L#BZ.8?___^?J+$@O!"\U`7````'T
M*C4!<````7PO!2\*+S4!<````?A(>/__2'@``2\(8?___^B"3^\`)$AX`<`O
M#F'____DLE"/4H!F`/ZH8`#^E"\(+T@`,&'____\!EB/(B\`_"`3(&\`++"!
M9@`#!B](`01,WWS\3^\`U&#____HFBXO`$AA____YQ2PAV8`_H@@+P!``H``
M``'_#(````'`9@#^="\&8?___^=")$@O`B\U`7````($8?___^PX3^\`#$J(
M9P`!;"\(+Q1A____\M(L"%"/9P`!6B\&8?___^9L6(\N`'`#L(=D+B\U`7``
M``((($9(<'C\8?___^A64(]*@&84<`2PAV<``BH@1@PP`"]X^V<``AXO`B0U
M`7````&<+P)A____Z\I0CTJ(9P`!!A`09P`!``P``#!G``#X+S4!<````;PO
M`F'____N9F'____CBB0U`7````%4+P(O`"\%+PXO-0%P```"&$AX__](>``!
M+PIA____YS9/[P`H*'4!<````AQ(>`'`+PIA____XUY0CU*`9D9A____XRIP
M$;"09CI2A&'____C,"\"+P0O`"\%+PXO#$AX__](>``!+PIA____YNA/[P`D
M2'@!P"\*8?___^,84(]2@&>Z+PYA____Y(8O"B\#8?___^W"+PIA____^F1/
M[P`08`#]."\`+PXO%"\U`7````'\2'@``2!U`7````$P+Q!A____XS)/[P`8
ME<I@`/T,+!1@`/ZD0J<O!F'____C!"A`4(]*@&<`_O@O`&'____XIBP`+@%8
MCTJ&;0#^Y$*G</]R]M*'T88O`2\`+PQA____YLQ(>``&0>\`X2\(+PPO2`!(
M8?___^.^3^\`'"!O`"Q=@&8``.`,D`!#04-F`/Z@#&A(10`$9@#^ED*G</]R
MSM*'T88O`2\`+PQA____YGY(>``H)`\&@@```.<O`B\,8?___^-P3^\`''(H
MLH!F``"40B\`^R\U`7````%4+P(O!2\.+S4!<````A1(>/__2'@``2\*8?__
M_^6F3^\`("\.8?___^-6+PHO`V'____LDB\*8?____DT3^\`$&``_`@H;``$
M2HQG`/W<+PQA____Y`98CW(#LH!D`/W*+S4!<````@Q(=`C\8?___^7R4(]*
M@&8`_;`L#&``_:IA____Y)XO-0%P```"$&'____W0%&/2.<P/$O[`7```*B0
M)'4!<````20O4@`<8?___^3\T?4!<````0`F4!=K`&8`9W08U(\O`B\U`7``
M``&48?___^DL4(]*B&<(#!``,6<``:9A____\I9A____Y+[1]0%P```!`"90
M2'@``TAX``$O-0%P```"("\+8?___^'T)DA/[P`02HAG.B\U`7````(D(&@`
M#"\08?___^1^*'4!<````0#9R"\48?___^'L(&L`#"!03^\`#`@H``8`"68`
M`=1(>``#2'@``2\U`7````(H8?___^1"*'4!<````0#9R"\48?___^&()DA/
M[P`02HAG+"\"+S4!<````71A____Z&I0CTJ(9P`!#"\((&L`#"\0+Q1A____
MX7Y/[P`,2'@``2\U`7````(L8?___^/H)G4!<````0#7R"\38?___^!2+S4!
M<````C`O""\38?___^%$(%-"*`!G+P(O-0%P```!<&'____H`B0()G4!<```
M`CPFB$_O`"!G4$AX`<`O`F'____?Y"(`4H%0CW8!MH%D)'(1LH!G'B\`+P(@
M=0%P```"0"!0+Q`O-0%P```".&'____C."(O`!P@$K"!9@``X$S?/`Q0CTYU
M('4!<````D`O$&'____WN"0()HA8CV:8+S4!<````C1A____XOY**``!9P#^
M;&'____PZF'____C$M'U`7````$`)E!@`/Y2('4!<````D`@4"\0(&L`#"\0
M8?___^O*4(](>``!+S4!<````BQA____XM@F=0%P```!`-?(+Q-A____WT(O
M-0%P```","\(+Q-A____X#0@4T(H`&<O`B\U`7````%P8?___^;R)`@F=0%P
M```"/":(3^\`(&8`_O!@`/\\+P@O%&'____AW%"/8`#^(&'____AY$Y6__A(
MYR`T2_L!<```I>(F;@`()'4!<````20M4O_\2&[_^"\U`7````&<8?___^:2
M4(]*B&<2$!!G#@P``#!G"$J+9P1*$V84(B[__"`2L(%F;$SN+`3_Z$Y>3G4O
M"V'____O#B0(2'@`+R\(8?___]^03^\`#$J(9P0D"%*"+P)A____XF!(>``$
M+S4!<````?0O"&'____B$$_O`!!*@&:F(B[__"`2L(%F$BU+``A,[BP$_^A.
M7F#____G'F'____A'DYQ3^_])$CG/SY+^P%P``"E&B]O`PP`7"]U`7````$D
M`(`@;P"`+U`#!#)\`#C3[P!<(@\&@0```(0T?`!XU>\`7"!!(!$A:0`$``Q0
MB4*0(4``!$*H``A!Z``0L\IFY"AO`.PN+P#P)&\`]"8O`/@B;P#\*"\!`"0O
M`(0@+P"(+&\`C"9O`)`P?``0T<$&@0```A`O00!4(@PH0R]``$`O2P`X)@@L
M$"HH``10B"9#("L`,+V`)BL`-+N#L8&_@[6!("\`0+&#)`D@!-*!XYN3R2@#
MB(%"J`!H(40`;"(*+@PD0BA`)`XO;P`X`$"Q[P!49U8L1B]%`#@F""P0*B@`
M!%"()D,@*P`PO8`F*P`TNX.Q@;^#M8$@+P!`L8,D"2`$TH'CFY/)*`.(@4*H
M`&@A1`!L(@HN#"1"*$`D#B]O`#@`0+'O`%1FJB!O`%PO4``P+V@`!``T+V@`
M"`!@+V@`#`!D+V@`$`!4+V@`%`!8+V@`&`!H+V@`'`!L+V@`(`!X+V@`)`!\
M("\`,.N((B\`-.N90H)"@R8!AH`@+P"$(B\`B$*$!H%:@GF9T80J+P!XTJ\`
M?-&%TH/1@B0O`%@L+P!LO8+$KP!D(`:U@$*$0H4J`=J`(B\`9.2)("\`8'X>
M[ZB`@2(O`&3OJ20O`&`F+P!DXHKBD^**XI.`@BQ`@H,H097*E\LF020O`(PF
M+P"00H`&@UJ">9G5@"(O`&C6KP!LU8$N+P!4+`J]ARPO`%@@#+&&SJ\`,,RO
M`#0@1BP'(B\`5+.&+@@@+P!8L8?>@]V")@5R&^*K)`3KBH2#)@7KBRP#C()"
M@D*#)@?6ABPO`#3DCBXO`#!P'N&OCH8@1R(O`#3AJ2PO`#`N+P`TXH[BE^*.
MXI<@"("&+T``0(*'+T$`3$*O`#A"KP`\+T$`/"PO`)0N+P"80H`&AUJ">9G=
M@"!&(D<L+P!4+B\`6"`(WHG=@"!&(D<@#B(O`$"S@"(,+"\`3+V!P(3"A2X*
MOX`L#+V!+`@N"=Z!W8`@1B)'(@-^&^ZI(`+KB("!(@/KB8*`($%"@$*!(@G2
MB"P%Y(XB1BX$?![MKRP)C(<@1BX%?![MKR)'XHSBE>*,XI4N"(Z$($<L"8R%
M(D9"KP!$0J\`2"]&`$@H+P"<*B\`H$*'!H5:@GF9V8<L"BX+WH7=A"1&)D<L
M+P!`+@B_ABXO`$PH";F'S(+.@R@O`#B]A"HO`#R_A2P*+@O>A=V$*@%X&^BM
M*`#KC(B%*@'KC2P%C(1"A$*%*@?:ABP#Y(XD1BX"?![MKRP*CH8F1RX#?![M
MKR1'+`(N`^*.XI?BCN*7)`N$AB]"`$`F"H:'*$-"KP!,0J\`4"]#`%`L+P"D
M+B\`J$*"!H=:@GF9W8(D+P`X)B\`/-:'U88O0@`X+T,`/"8(+"\`0+V#+@DD
M#+6'QH#.@2PO`$2]@R1#)`FUAR9'+"\`."XO`#PD"MZ+W8(D1B9'+@5V&^:O
M+`3KCHR'+@7KCXZ&($="AD*'+@O>B"0!Y(H@0B8`=![EJR0(A(,F0B8!=![E
MJR1#)``F`>**XI/BBN*3($(B0R8+(`B&@"]#`'`B"B0)@H(L04*O`#A"KP`\
M+T$`/"`O`*PB+P"P0H(&@5J">9G1@B!`(D$@+P!$(B\`2"0(THG1@B!`(D$F
M+P!`("\`<+&#)`PB#K."QH3$A21")`,@+P!,L8(F"B(,LX,@""()TH/1@B!`
M(D$F!W(;XJLD!NN*A(,F!^N+AH(@0T*"0H,F"=:((`7DB"!`(@1P'N&I(`B`
M@29`(@5P'N&I)$$@!"(%XHCBD>*(XI$@0")!(@LH"(*$+T$`0"H*(`F*@"A%
M0J\`1$*O`$@O10!(*"\`M"HO`+A"@`:%6H)YF=F`($0B12@O`$PJ+P!0(`C:
MB=F`($0B12(O`'`H+P!`N8$@#BH,NX#"AL"')$`@`2@O`#BY@"(**@Z[@2@(
M*@G:@=F`($0B12(#>AOJJ2`"ZXB`@2(#ZXF"@"!!0H!"@2()TH@H!^2,($0J
M!G@>Z:TH"(B%)D0J!W@>Z:TD12@&*@?BC.*5XHSBE2!$(D4J"RP(BH8O10!P
M+@HH"8Z$+$="KP!,0J\`4"]'`%`J+P"\+"\`P$*'!H9:@GF9VX<@12)&*"\`
M."HO`#PL"-J)V88@1")%*B\`0"XO`'"_A2@,+`Z]A,J"R(,D1"@%+B\`1+^$
M*@HL#+V%+`@N"=Z%W80@1B)'*@%^&^ZM*`#KC(B%*@'KC8J$($5"A$*%*@G:
MB"P#Y(X@1BX"?![MKRP(C(<F1BX#?![MKR1'+`(N`^*.XI?BCN*7($8B1RX+
M)`B.@B]'`$`F"BP)AH8H0T*O`#A"KP`\+T,`/"0O`,0F+P#(0H8&@UJ">9G5
MAB!"(D,D+P!$)B\`2"P(UHG5AB!"(D,N+P!P)"\`0+6'+`XF#+>&SH#,@21&
M+`<D+P!,M88N"B8.MX<D""8)UH?5AB!"(D,N!78;YJ\L!.N.C(<N!>N/CH8@
M1T*&0H<N"=Z()`'DBB!")@!T'N6K)`B$@R9")@%T'N6K)$,D`"8!XHKBD^**
MXI,@0B)#)@L@"(:`+T,`<"(*)`F"@BQ!0J\`1$*O`$@O00!(("\`S"(O`-!"
M@@:!6H)YF=&"($`B02`O`$PB+P!0)`C2B=&"($`B028O`$`@+P!PL8,D#"(.
MLX+&A,2%)$(D`R`O`#BQ@B8*(@RS@R`((@G2@]&"($`B028'<AOBJR0&ZXJ$
M@R8'ZXN&@B!#0H)"@R8)UH@@!>2(($`B!'`>X:D@"("!)D`B!7`>X:DD02`$
M(@7BB.*1XHCBD2!`(D$B"R@(@H0O00!`*@H@"8J`*$5"KP!,0J\`4"]%`%`H
M+P#4*B\`V$*`!H5:@GF9V8`@1")%*"\`."HO`#P@"-J)V8`@1")%(B\`<"@O
M`$"Y@2`.*@R[@,*&P(<D0"`!*"\`1+F`(@HJ#KN!*`@J"=J!V8`@1")%(@-Z
M&^JI(`+KB("!(@/KB8*`($%"@$*!(@G2B"@'Y(P@1"H&>![IK2@(B(4F1"H'
M>![IK21%*`8J!^*,XI7BC.*5($0B12H++`B*AB]%`'`N"B@)CH0L1T*O`#A"
MKP`\+T<`/"HO`-PL+P#@0H<&AEJ">9G;AR!%(D8H+P!$*B\`2"P(VHG9AB!$
M(D4J+P!`+B\`<+^%*`PL#KV$RH+(@R1$*`4N+P!,OX0J"BP,O84L""X)WH7=
MA"!&(D<J`7X;[JTH`.N,B(4J`>N-BH0@14*$0H4J"=J(+`/DCB!&+@)\'NVO
M+`B,AR9&+@-\'NVO)$<L`BX#XH[BE^*.XI<@1B)'+@LD"(Z"+T<`0"8*+`F&
MABA#0J\`1$*O`$@O0P!()"\`Y"8O`.A"A@:#6H)YF=6&($(B0R0O`$PF+P!0
M+`C6B=6&($(B0RXO`'`D+P!`M8<L#B8,MX;.@,R!)$8L!R0O`#BUABX*)@ZW
MAR0()@G6A]6&($(B0RX%=AOFKRP$ZXZ,ARX%ZX^.AB!'0H9"ARX)WH@D`>2*
M($(F`'0>Y:LD"(2#)D(F`70>Y:LD0R0`)@'BBN*3XHKBDR!"(D,F"R`(AH`O
M0P!P(@HD"8*"+$%"KP!,0J\`4"]!`%`@+P#L(B\`\$*"!H%:@GF9T8(@0")!
M("\`."(O`#PD"-*)T8(@0")!)B\`0"`O`'"Q@R0,(@ZS@L:$Q(4D0B0#("\`
M1+&")@HB#+.#(`@B"=*#T8(@0")!)@=R&^*K)`;KBH2#)@?KBX:"($-"@D*#
M)@G6B"`%Y(@@0"($<![AJ2`(@($F0"(%<![AJ21!(`0B!>*(XI'BB.*1($`B
M02(+*`B"A"]!`$`J"B`)BH`H14*O`#A"KP`\+T4`/"@O`/0J+P#X0H`&A5J"
M>9G9@"!$(D4H+P!$*B\`2"`(VHG9@"!$(D4B+P!P*"\`0+F!(`XJ#+N`PH;`
MAR1`(`$H+P!,N8`B"BH.NX$H""H)VH'9@"!$(D4B`WH;ZJD@`NN(@($B`^N)
M@H`@04*`0H$B"=*(*`?DC"!$*@9X'NFM*`B(A29$*@=X'NFM)$4H!BH'XHSB
ME>*,XI4@1")%*@LL"(J&+T4`<"X**`F.A"Q'0J\`1$*O`$@O1P!(*B\`_"PO
M`0!"AP:&6H)YF=N'($4B1B@O`$PJ+P!0+`C:B=F&($0B12HO`$`N+P!POX4H
M#"P.O83*@LB#)$0H!2XO`#B_A"H*+`R]A2P(+@G>A=V$($8B1RH!?AONK2@`
MZXR(A2H!ZXV*A"!%0H1"A2H)VH@L`^2.(D8N`GP>[:\L"8R'($8N`WP>[:\B
M1^**XI/BBN*3+@B.@B!'+`F,@R)&0J\`3$*O`%`O1@!0)"\!!"8O`0A"AP:#
M6H)YF=6'+"\`."XO`#S>@]V")$8F1RXO`'`D"+6'+`XF";>&SH#,@20O`$2_
M@B8.O8,L"BX+WH/=@B8%=!ODJR0$ZXJ$@R8%ZXLL`XR"0H)"@R8'UH8L`>2.
M)$8N`'P>[:\L"HZ&)D<N`7P>[:\D1RP`+@'BCN*7XH[BER`+@(8H0"`*@(="
MKP`X0J\`/"]``#PL+P$,+B\!$$*!!H=:@GF9W8$D1B9'+"\`1"XO`$@B"MZ+
MW8$O1@!$+T<`2"P(+@R_AB()L8',A,*%+B\`3+^&)$8L";V!)D$L+P!$+B\`
M2"(*WHO=@2]&`$0O1P!(+`-^&^ZN($8L`NN.(@B,@2X#ZX^.AI7*E\LF1]?O
M`$@N!>2/+`1R'N.NC(<N!>.OXHSBE>*,XI6,A(Z%0J\`1$*O`$@O1P!(*"\!
M%"HO`1A"@0:%6H)YF=F!($0B12@O`$PJ+P!0(@C:B=F!+T0`3"]%`%`B#+V!
MOX#"@L"#($`@`2@O`#BY@"((*B\`/+N!*"\`3"HO`%#:@=F`+T0`3"]%`%`J
M"NN-($4@"^N80H1"A2H`(@B*@2`O`$PB+P!0TH71A"]``$PO00!0D<B3R2)!
M*`/DC"`"<A[CJ("$(@-X'NFIXHKBD^**XI.$@(*#*$$@+P$<(B\!($*%!H%:
M@GF9T84F+P`XTJ\`/-&#M88H#+F'*@K,A20+SH(D+P!$O8(F+P!(OX/6@=6`
M*`CKC"P)ZYY"@$*!(@:"A"@"*@/:@=F`+T0`."]%`#Q"AD*'+@4D"WH>ZZH@
M"B(+XHCBD>*(XI&$@29")"\!)"8O`2A"@`:#;MGKH=6`(B\`1-:O`$C5@2@,
M*@N[A$*`0H$B+P!0N8'2@]&"*`;KC"H'ZYU"@D*#)@6&A"@`*@':@]F"+T0`
M1"]%`$A"A$*%*B\`2"`)<A[CJ"0()@GBBN*3XHKBDX"#)$`D+P$L)B\!,$*`
M!H-NV>NAU8"1R)/)(DP@""()TH/1@B!`(D$@"R(*LX!"@D*#)B\`/+&#(`@B
M"=*#T8(@0")!(`3KB"(%ZYE"@D*#)@&&@"`((@G2@]&"($`B04*"0H,F"2`'
M<A[CJ.*.XI?BCN*7@(<@0"PO`30N+P$X0H`&AV[9ZZ'=@$*O`#A"KP`\+TL`
M/"`O`#@B+P`\TH?1AB9`*$$@"B((LX!"AD*'+@6QAR`+(@S2A]&&+T``."]!
M`#PB`NN))D$L">N>0H!"@2(&+@N"ARPO`#@N+P`\WH'=@"]&`$0O1P!(0H!"
M@2('+`5^'N^NXHSBE>*,XI6,A2Q&*"\!/"HO`4!"A@:%;MGKH=F&E\N9S"A*
M+@O:C-F')$0F12@(*@Z[A$*O`#A"KP`\MX0O1``\*"\`."HO`#PL"MJ+V88D
M1"9%+@#KCR@!ZYQ"KP`X0J\`/(B'+T0`/"HO`#@L+P`\+@K<B]N')$4F1D*$
M0H4J"RP)?A[OKN**XI/BBN*3C(,B1B0O`40F+P%(0H8&@V[9ZZ'5AD*O`#A"
MKP`\+T@`/"PO`#@N+P`\WH/=@B]&`#@O1P`\+@DD#K6'0H)"@R8'+"\`2+V#
M+"\`."XO`#S>@]V"+T8`."]'`#PN!.N/)`OKFB!"0H)"@R8(AH<L+P`X+B\`
M/-Z#W8(O1@`X+T<`/$*"0H,F!RX!?![MK^*(XI'BB.*1CH$O1P!`("\!3"(O
M`5!"A@:!;MGKH=&&0H9"ARX.TH?1AB]``$0O00!(+`DN+P!`OX9"KP!,0J\`
M4"`+O8`O0`!0+"\`1"XO`$@@+P!,WJ\`4-V`)$8F1RP"ZXXB`^N90J\`1$*O
M`$B"AB]!`$@L+P!$+B\`2"`*WHO=@"1&)D="@$*!(@LL!7X>[Z[BC.*5XHSB
ME8R%+$8H+P%4*B\!6$*&!H5NV>NAV89"AD*'+@G:A]F&($0B12XO`$`H#KF'
M0J\`1$*O`$@J+P`\NX<O1P!(+"\`1"XO`$@H"-Z)W80@1B)'*@#KC2P+ZYY"
MKP`X0J\`/(R%+T8`/"@O`#@J+P`\+`C:B=F&($0B14*$0H4J"2X#?![MK^**
MXI/BBN*3CH,@1R0O`5PF+P%@0H<&@V[9ZZ'5AT*O`#A"KP`\+V\`0``\+"\`
M."XO`#S>@]V"+T8`."]'`#PN""0.M8="@D*#)@N_@RPO`#@N+P`\WH/=@B1&
M)D<N!.N/)`GKFBA"0H)"@R8,AH<L"BX+WH/=@B1&)D="@D*#)@LN`7P>[:_B
MB.*1XHCBD8Z!+T<`0"`O`60B+P%H0H8&@6[9ZZ'1AD*&0H<N#M*'T88O0``X
M+T$`/"P(+B\`0+^&0J\`1$*O`$@@";V`+T``2"PO`#@N+P`\("\`1-ZO`$C=
M@")&)$<L`NN.(@OKF4*O`#A"KP`\@H8O00`\+"\`."XO`#P@"=Z*W8`B1B1'
M0H!"@2(*+`5^'N^NXHSBE>*,XI6,A2Q&*"\!;"HO`7!"A@:%;MGKH=F&0H9"
MARX(VH?9AB!$(D4N+P!`*`ZYAT*O`#A"KP`\MX<O1P`\+"\`."XO`#PH"-Z)
MW80@1B)'*@#KC2P*ZYY"KP`X0J\`/(R%+T8`/"@O`#@J+P`\+`C:B=F&($0B
M14*$0H4J"2X+?![MK^**XI/BBN*3CH,@1R0O`70F+P%X0H<&@V[9ZZ'5AY?+
MF<PH;P!`+`LN#-Z#W8(F1BA'+@@D#K6'0H)"@R8*OX,L"RX,WH/=@B1&)D<N
M!.N/)`GKFBA"0H)"@R8,AH<L"BX+WH/=@B1&)D="@D*#)@LN`7P>[:_BB.*1
MXHCBD8Z!+T<`0"`O`7PB+P&`0H8&@6[9ZZ'1AD*&0H<N#M*'T88O0``X+T$`
M/"P(+B\`0+^&0J\`1$*O`$@@";V`+T``2"PO`#@N+P`\("\`1-ZO`$C=@")&
M)$<L`NN.(@OKF4*O`#A"KP`\@H8O00`\+"\`."XO`#P@"=Z*W8`B1B1'0H!"
M@2(*+`5^'N^NXHSBE>*,XI6,A2Q&*"\!A"HO`8A"A@:%;MGKH=F&0H9"ARX(
MVH?9AB!$(D4N+P!`*`ZYAT*O`#A"KP`\MX<O1P`\+"\`."XO`#PH"-Z)W80@
M1B)'*@#KC2P*ZYY"KP`X0J\`/(R%+T8`/"@O`#@J+P`\+`C:B=F&($0B14*$
M0H4J"2X+?![MK^**XI/BBN*3CH,@1R0O`8PF+P&00H<&@V[9ZZ'5AY?+F<PH
M;P!`+`LN#-Z#W8(F1BA'+@@D#K6'0H)"@R8*OX,L"RX,WH/=@B1&)D<N!.N/
M)`GKFBA"0H)"@R8,AH<L"BX+WH/=@B1&)D="@D*#)@LN`7P>[:_BB.*1XHCB
MD8Z!+T<`0"`O`90B+P&80H8&@6[9ZZ'1AD*&0H<N#M*'T88O0``X+T$`/"P(
M+B\`0+^&0J\`1$*O`$@@";V`+T``2"PO`#@N+P`\("\`1-ZO`$C=@")&)$<L
M`NN.(@OKF4*O`#A"KP`\@H8O00`\+"\`."XO`#P@"=Z*W8`B1B1'0H!"@2(*
M+`5^'N^NXHSBE>*,XI6,A2Q&*"\!G"HO`:!"A@:%;MGKH=F&0H9"ARX(VH?9
MAB!$(D4N+P!`*`ZYAT*O`#A"KP`\MX<O1P`\+"\`."XO`#PH"-Z)W80@1B)'
M*@#KC2P*ZYY"KP`X0J\`/(R%+T8`/"@O`#@J+P`\+`C:B=F&($0B14*$0H4J
M"2X+?![MK^**XI/BBN*3CH,@1R0O`:0F+P&H0H<&@V[9ZZ'5AY?+F<PH;P!`
M+`LN#-Z#W8(F1BA'+@@D#K6'0H)"@R8*OX,L"RX,WH/=@B1&)D<N!.N/)`GK
MFBA"0H)"@R8,AH<L"BX+WH/=@B1&)D="@D*#)@LN`7P>[:_BB.*1XHCBD8Z!
M)$<@+P&L(B\!L$*'!H%NV>NAT8="KP`X0J\`/"].`#PL+P`X+B\`/-Z!W8`O
M1@`X+T<`/"X((`JQAT*`0H$B![N!+"\`."XO`#S>@=V`+T8`."]'`#PN`NN/
M(`OKF"A`0H!"@2(,@H<L+P`X+B\`/-Z!W8`O1@`X+T<`/$*&0H<N+P`\(`ER
M'N.HXHSBE>*,XI6`A2)`*"\!M"HO`;A"@`:%;MGKH=F`+T0`1"]%`$A"A$*%
M*@@@+P!$(B\`2-*%T80O0`!$+T$`2"(**`FY@4*$0H4J`;>%("\`1"(O`$C2
MA=&$(`=X&^BH*`;KC(B`*@?KC2`%@(27RYG,*$'9P"(#Y(DJ`G`>X:V*@2@#
MX:SBBN*3XHKBDXJ"+$6(@T*O`$Q"KP!0+T0`4"`O`;PB+P'`0H(&@6[9ZZ'1
M@D*"0H,F"M*#T8(F";F#($-"@D*#)@B_@]*#T8(@#'0;Y*@D"^N*A(`F#.N+
M(`.`@D*"0H,F`=:`(`?DB"(&>A[KJ8*`(`?KJ.*.XI?BCN*7@H8@08"')$!"
MKP`X0J\`/"]``#PL+P'$+B\!R$*`!H>/&[S<W8!"@$*!(@G>@=V`+T8`1"]'
M`$@J#B((BH$L"HB&(@O"A2`,P(0N+P!,SJ\`."PO`%#,KP`\*`&(ARH`BH8N
M+P!$VJ\`2-F'(@-P&^"I(`+KB("!(@/KB2@!B(!"@$*!(@72A"H,Y(TH"WP>
M[:R(A2H,[:TL"RX,XH[BE^*.XI>(AB]$`$"*ARA%0J\`1$*O`$@O10!(+@B.
MA"@*B(7.@LB#*B\`.,JO`$0L"LRO`$B.A2]'`'"(AB]$`'0H+P',*B\!T$*&
M!H6/&[S<V88@1")%*"\`3"HO`%`L"-J)V88@1")%*"\`<"HO`'0L"-J)V88@
M1")%+@%X&^BO+`#KCHR'+@'KCXZ&($="AD*'+@G>B"H#Y(T@12@">A[KK"H(
MBH0D12@#>A[KK"9$*`(J`^*,XI7BC.*5($0B12H*)`B*@B]%`"PF"R@)AH0L
M0T*O`$Q"KP!0+T,`4"@O`$"(A2H,BH/(@,J!($4J+P!$RJ\`3"0,Q(.(A2]$
M`'`F"(:"+T,`="@O`=0J+P'80H(&A8\;O-S9@B!$(D4F+P`X*"\`/"H(V(G7
MA2!#(D0D+P!P)B\`="@(UHG5A"!"(D,J!W0;Y*TH!NN,B(4J!^N-BH0@14*$
M0H4J"=J()@'DBR!#)`!V'N>J)@B&@B1#)`%V'N>J)D(D`"8!XHKBD^**XI,@
M0B)#)@H@"(:`+T,`0"(+)`F"@BA!0J\`.$*O`#PO00`\)B\`+(:O`$`D#H2!
MQH8B0\2')B\`3,:O`#@@#L"!(@F"@R]!`'"$@"]"`'0D+P'<)B\!X$*`!H./
M&[S<U8`@0B)#(B\`1"0O`$@F"-2)TX,@02)"("\`<"(O`'0D"-*)T8(@0")!
M)@5P&^"K)`3KBH2#)@7KBX:"($-"@D*#)@G6B"('Y(D@02`&<A[CJ"((@H`D
M02`'<A[CJ"9`(`8B!^*(XI'BB.*1($`B02(*+`B"AB]!`"PN"R`)CH`L1T*O
M`$1"KP!(+T<`2"(O`$""KP`L(`R`A\*$(D'`A2(O`#C"KP!$+`S,ARX)CH$O
M1P!P@(8O0`!T("\!Y"(O`>A"A@:!CQN\W-&&($`B02`O`$PB+P!0+`C2B=&&
M($`B02`O`'`B+P!T+`C2B=&&($`B02(#?AONJ2`"ZXB`@2(#ZXF"@"!!0H!"
M@2()TH@L!>2.($8N!'P>[:\L"(R')$8N!7P>[:\F1RP$+@7BCN*7XH[BER!&
M(D<N"B@(CH0O1P!`*@LL"8J&*$5"KP!,0J\`4"]%`%`N+P`LCJ\`0"P.C(7.
M@B)'S(,N+P!$SJ\`3"@.R(4J"8J'+T4`<(R$+T8`="PO`>PN+P'P0H0&AX\;
MO-S=A"!&(D<J+P`X+"\`/"X(W(G;AR!%(D8H+P!P*B\`="P(VHG9AB!$(D4N
M`7@;Z*\L`.N.C(<N`>N/CH8@1T*&0H<N"=Z(*@/DC2!%*`)Z'NNL*@B*A"1%
M*`-Z'NNL)D0H`BH#XHSBE>*,XI4@1")%*@HD"(J"+T4`+"8+*`F&A"Q#0J\`
M.$*O`#PO0P`\*B\`0(JO`"PH#(B#RH`B1<B!*B\`3,JO`#@D#,2#)@F&A2]#
M`'"(@B]$`'0H+P'T*B\!^$*"!H6/&[S<V8(@1")%)B\`1"@O`$@J"-B)UX4@
M0R)$)"\`<"8O`'0H"-:)U80@0B)#*@=T&^2M*`;KC(B%*@?KC8J$($5"A$*%
M*@G:B"8!Y(L@0R0`=A[GJB8(AH(D0R0!=A[GJB9")``F`>**XI/BBN*3($(B
M0R8*(`B&@"]#`$`B"R0)@H(H04*O`$1"KP!(+T$`2"8O`"R&KP!`)`Z$@<:&
M(D/$AR8O`#C&KP!$(`[`@2()@H,O00!PA(`O0@!T)"\!_"8O`@!"@`:#CQN\
MW-6`($(B0R(O`$PD+P!0)@C4B=.#($$B0B`O`'`B+P!T)`C2B=&"($`B028%
M<!O@JR0$ZXJ$@R8%ZXN&@B!#0H)"@R8)UH@B!^2)($$@!G(>XZ@B"(*`)$$@
M!W(>XZ@F0"`&(@?BB.*1XHCBD2!`(D$B"BP(@H8O00`L+@L@"8Z`+$="KP!,
M0J\`4"]'`%`B+P!`@J\`+"`,@(?"A")!P(4B+P!$PJ\`3"P,S(<N"8Z!+T<`
M<("&+T``="`O`@0B+P((0H8&@8\;O-S1AB!`(D$@+P`X(B\`/"P(THG1AB!`
M(D$@+P!P(B\`="P(THG1AB!`(D$B`WX;[JD@`NN(@($B`^N)@H`@04*`0H$B
M"=*(+`7DCB!&+@1\'NVO+`B,AR1&+@5\'NVO)D<L!"X%XH[BE^*.XI<@1B)'
M+@HH"(Z$+T<`0"H++`F*ABA%0J\`.$*O`#PO10`\+B\`+(ZO`$`L#HR%SH(B
M1\R#+B\`3,ZO`#@H#LB%*@F*AR]%`'",A"]&`'0L+P(,+B\"$$*$!H>/&[S<
MW80@1B)'*B\`1"PO`$@N"-R)VX<@12)&*"\`<"HO`'0L"-J)V88@1")%+@%X
M&^BO+`#KCHR'+@'KCXZ&($="AD*'+@G>B"H#Y(T@12@">A[KK"H(BH0D12@#
M>A[KK"9$*`(J`^*,XI7BC.*5($0B12H*)`B*@B]%`"PF"R@)AH0L0T*O`$1"
MKP!(+T,`2"HO`$"*KP`L*`R(@\J`(D7(@2HO`#C*KP!$)`S$@R8)AH4O0P!P
MB((O1`!T*"\"%"HO`AA"@@:%CQN\W-F"($0B128O`$PH+P!0*@C8B=>%($,B
M1"0O`'`F+P!T*`C6B=6$($(B0RH'=!ODK2@&ZXR(A2H'ZXV*A"!%0H1"A2H)
MVH@F`>2+($,D`'8>YZHF"(:")$,D`78>YZHF0B0`)@'BBN*3XHKBDR!"(D,F
M"B`(AH`O0P!`(@LD"8*"*$%"KP!,0J\`4"]!`%`F+P`LAJ\`0"0.A('&AB)#
MQ(<F+P!$QJ\`3"`.P($B"8*#+T$`<(2`+T(`="0O`APF+P(@0H`&@X\;O-S5
M@"!"(D,B+P`X)"\`/"8(U(G3@R!!(D(@+P!P(B\`="0(THG1@B!`(D$F!7`;
MX*LD!.N*A(,F!>N+AH(@0T*"0H,F"=:((@?DB2!!(`9R'N.H(@B"@"1!(`=R
M'N.H)D`@!B('XHCBD>*(XI$@0")!(@HL"(*&+T$`+"X+(`F.@"Q'0J\`.$*O
M`#PO1P`\(B\`0(*O`"P@#("'PH0B0<"%(B\`3,*O`#@L#,R'+@F.@2]'`'"`
MAB]``'0@+P(D(B\"*$*&!H&/&[S<T88@0")!("\`1"(O`$@L"-*)T88@0")!
M("\`<"(O`'0L"-*)T88@0")!(@-^&^ZI(`+KB("!(@/KB8*`($%"@$*!(@G2
MB"P%Y(X@1BX$?![MKRP(C(<D1BX%?![MKR9'+`0N!>*.XI?BCN*7($8B1RX*
M*`B.A"]'`$`J"RP)BH8H14*O`$1"KP!(+T4`2"XO`"R.KP!`+`Z,A<Z"(D?,
M@RXO`#C.KP!$*`[(A2H)BH<O10!PC(0O1@!T+"\"+"XO`C!"A`:'CQN\W-V$
M($8B1RHO`$PL+P!0+@C<B=N'($4B1B@O`'`J+P!T+`C:B=F&($0B12X!>!OH
MKRP`ZXZ,ARX!ZX^.AB!'0H9"ARX)WH@J`^2-($4H`GH>ZZPJ"(J$)$4H`WH>
MZZPF1"@"*@/BC.*5XHSBE2!$(D4J"B0(BH(O10`L)@LH"8:$+$-"KP!,0J\`
M4"]#`%`J+P!`BJ\`+"@,B(/*@")%R($J+P!$RJ\`3"0,Q(,F"8:%+T,`<(B"
M+T0`="@O`C0J+P(X0H(&A8\;O-S9@B!$(D4F+P`X*"\`/"H(V(G7A2!#(D0D
M+P!P)B\`="@(UHG5A"!"(D,J!W0;Y*TH!NN,B(4J!^N-BH0@14*$0H4J"=J(
M)@'DBR!#)`!V'N>J)@B&@B1#)`%V'N>J)D(D`"8!XHKBD^**XI,@0B)#)@H@
M"(:`+T,`0"(+)`F"@BA!0J\`.$*O`#PO00`\)B\`+(:O`$`D#H2!QH8B0\2'
M)B\`3,:O`#@@#L"!(@F"@R]!`'"$@"]"`'0D+P(\)B\"0$*`!H./&[S<U8`@
M0B)#(B\`1"0O`$@F"-2)TX,@02)"("\`<"(O`'0D"-*)T8(@0")!)@5P&^"K
M)`3KBH2#)@7KBX:"($-"@D*#)@G6B"('Y(D@02`&<A[CJ"((@H`D02`'<A[C
MJ"9`(`8B!^*(XI'BB.*1($`B02(*+`B"AB]!`"PN"R`)CH`L1T*O`$1"KP!(
M+T<`2"(O`$""KP`L(`R`A\*$(D'`A2(O`#C"KP!$+`S,ARX)CH$O1P!P@(8O
M0`!T("\"1"(O`DA"A@:!CQN\W-&&($`B02`O`$PB+P!0+`C2B=&&($`B02`O
M`'`B+P!T+`C2B=&&($`B02(#?AONJ2`"ZXB`@2(#ZXF"@"!!0H!"@2()TH@L
M!>2.(D8N!'P>[:\L"8R'($8N!7P>[:\B1^*,XI7BC.*5+@B.A"]'`$`L"8R%
M*$9"KP!,0J\`4"]&`%`N+P`LCJ\`0"P.*`R,A,Z"S(,@1BHO`$3*KP!,+`[,
MA(Z%+T<`<"X(CH8O1P!T*"\"3"HO`E!"A@:%CQN\W-F&($0B12@O`#@J+P`\
M+`C:B=F&($0B12PO`'`N+P!T*`C>B=V$*@%X&^BM+`#KCHR%*@'KC8J&($65
MRI?+1_!X`"X#Y(\L`G@>Z:Z,ARX#Z:_BBN*3XHKBDXR"+$:&AT*O`#A"KP`\
M+T,`/"@&B*\`0"H,BH/(@,J!+"\`3,RO`#@N#,Z#C(2.A2@O`E0J+P)80H(&
MA8\;O-S9@B!$(D4H+P!$*B\`2"0(VHG9@MJ'V88O1`!$+T4`2"H*ZXTL"^N>
M(D9"AD*'+@F.A2@O`$0J+P!(VH?9AB]$`'`O10!TD<B3R2)%*@'DC2@`?![M
MK(B%*@'MK>*(XI'BB.*1B(""A4*O`$1"KP!(+T$`2"0.A(2&@2X*Q(<@"\:`
M+"\`.,RO`$0@+P`\P($H`HB&*@.*@"0O`EPF+P)@0H8&@X\;O-S5ABXO`$S6
MKP!0U8?6A=6$(`CKB"P)ZYY"A$*%*@:*@"P"+@/>A=V$+T8`3"]'`%!"AD*'
M+B\`4"`+=![EJ"0*)@OBBN*3XHKBDX"#)D`D+P)D)B\":$*$!H/*8L'6U80J
M+P`XUJ\`/-6%*`"SA$*`0H$B+P!TN8'2@]&"*`;KC"H'ZYU"@D*#)@6&A"@`
M*@':@]F"+T0`<"]%`'1"A$*%*B\`="`)<A[CJ"0()@GBBN*3XHKBDX"#)$`D
M+P)L)B\"<$*`!H/*8L'6U8`@+P!$(B\`2-*#T8(@0")!(`LB"K.`0H)"@R8'
ML8,@""()TH/1@B!`(D$@!.N((@7KF4*"0H,F`8:`(`@B"=*#T8(@0")!0H)"
M@R8)(`=R'N.HXH[BE^*.XI>`AR!`+"\"="XO`GA"@`:'RF+!UMV`0J\`.$*O
M`#PO2P`\("\`."(O`#S2A]&&)D`H02`*(@BS@$*&0H<N!;&'(`LB#-*'T88O
M0``X+T$`/"("ZXDF02P)ZYY"@$*!(@8N"X*'+"\`."XO`#S>@=V`+T8`1"]'
M`$A"@$*!(@<L!7X>[Z[BC.*5XHSBE8R%+$8H+P)\*B\"@$*&!H7*8L'6V8:7
MRYG,*$HN"]J,V8<D1"9%*`@J#KN$0J\`.$*O`#RWA"]$`#PH+P`X*B\`/"P*
MVHO9AB1$)D4N`.N/*`'KG$*O`#A"KP`\B(<O1``\*B\`."PO`#PN"MR+VX<D
M129&0H1"A2H++`E^'N^NXHKBD^**XI.,@R)&)"\"A"8O`HA"A@:#RF+!UM6&
M0J\`.$*O`#PO2``\+"\`."XO`#S>@]V"+T8`."]'`#PN"20.M8="@D*#)@<L
M+P!(O8,L+P`X+B\`/-Z#W8(O1@`X+T<`/"X$ZX\D"^N:($)"@D*#)@B&ARPO
M`#@N+P`\WH/=@B]&`#@O1P`\0H)"@R8'+@%\'NVOXHCBD>*(XI&.@2]'`$`@
M+P*,(B\"D$*&!H'*8L'6T89"AD*'+@[2A]&&+T``1"]!`$@L"2XO`$"_AD*O
M`$Q"KP!0(`N]@"]``%`L+P!$+B\`2"`O`$S>KP!0W8`D1B9'+`+KCB(#ZYE"
MKP!$0J\`2(*&+T$`2"PO`$0N+P!((`K>B]V`)$8F1T*`0H$B"RP%?A[OKN*,
MXI7BC.*5C(4L1B@O`I0J+P*80H8&A<IBP=;9AD*&0H<N"=J'V88@1")%+B\`
M0"@.N8="KP!$0J\`2"HO`#R[AR]'`$@L+P!$+B\`2"@(WHG=A"!&(D<J`.N-
M+`OKGD*O`#A"KP`\C(4O1@`\*"\`."HO`#PL"-J)V88@1")%0H1"A2H)+@-\
M'NVOXHKBD^**XI..@R!')"\"G"8O`J!"AP:#RF+!UM6'0J\`.$*O`#PO;P!`
M`#PL+P`X+B\`/-Z#W8(O1@`X+T<`/"X()`ZUAT*"0H,F"[^#+"\`."XO`#S>
M@]V")$8F1RX$ZX\D">N:*$)"@D*#)@R&ARP*+@O>@]V")$8F1T*"0H,F"RX!
M?![MK^*(XI'BB.*1CH$O1P!`("\"I"(O`JA"A@:!RF+!UM&&0H9"ARX.TH?1
MAB]``#@O00`\+`@N+P!`OX9"KP!$0J\`2"`)O8`O0`!(+"\`."XO`#P@+P!$
MWJ\`2-V`(D8D1RP"ZXXB"^N90J\`.$*O`#R"AB]!`#PL+P`X+B\`/"`)WHK=
M@")&)$="@$*!(@HL!7X>[Z[BC.*5XHSBE8R%+$8H+P*L*B\"L$*&!H7*8L'6
MV89"AD*'+@C:A]F&($0B12XO`$`H#KF'0J\`.$*O`#RWAR]'`#PL+P`X+B\`
M/"@(WHG=A"!&(D<J`.N-+`KKGD*O`#A"KP`\C(4O1@`\*"\`."HO`#PL"-J)
MV88@1")%0H1"A2H)+@M\'NVOXHKBD^**XI..@R!')"\"M"8O`KA"AP:#RF+!
MUM6'E\N9S"AO`$`L"RX,WH/=@B9&*$<N""0.M8="@D*#)@J_@RP++@S>@]V"
M)$8F1RX$ZX\D">N:*$)"@D*#)@R&ARP*+@O>@]V")$8F1T*"0H,F"RX!?![M
MK^*(XI'BB.*1CH$O1P!`("\"O"(O`L!"A@:!RF+!UM&&0H9"ARX.TH?1AB]`
M`#@O00`\+`@N+P!`OX9"KP!$0J\`2"`)O8`O0`!(+"\`."XO`#P@+P!$WJ\`
M2-V`(D8D1RP"ZXXB"^N90J\`.$*O`#R"AB]!`#PL+P`X+B\`/"`)WHK=@")&
M)$="@$*!(@HL!7X>[Z[BC.*5XHSBE8R%+$8H+P+$*B\"R$*&!H7*8L'6V89"
MAD*'+@C:A]F&($0B12XO`$`H#KF'0J\`.$*O`#RWAR]'`#PL+P`X+B\`/"@(
MWHG=A"!&(D<J`.N-+`KKGD*O`#A"KP`\C(4O1@`\*"\`."HO`#PL"-J)V88@
M1")%0H1"A2H)+@M\'NVOXHKBD^**XI..@R!')"\"S"8O`M!"AP:#RF+!UM6'
ME\N9S"AO`$`L"RX,WH/=@B9&*$<N""0.M8="@D*#)@J_@RP++@S>@]V")$8F
M1RX$ZX\D">N:*$)"@D*#)@R&ARP*+@O>@]V")$8F1T*"0H,F"RX!?![MK^*(
MXI'BB.*1CH$O1P!`("\"U"(O`MA"A@:!RF+!UM&&0H9"ARX.TH?1AB]``#@O
M00`\+`@N+P!`OX9"KP!$0J\`2"`)O8`O0`!(+"\`."XO`#P@+P!$WJ\`2-V`
M(D8D1RP"ZXXB"^N90J\`.$*O`#R"AB]!`#PL+P`X+B\`/"`)WHK=@")&)$="
M@$*!(@HL!7X>[Z[BC.*5XHSBE8R%+$8H+P+<*B\"X$*&!H7*8L'6V89"AD*'
M+@C:A]F&($0B12XO`$`H#KF'0J\`.$*O`#RWAR]'`#PL+P`X+B\`/"@(WHG=
MA"!&(D<J`.N-+`KKGD*O`#A"KP`\C(4O1@`\*"\`."HO`#PL"-J)V88@1")%
M0H1"A2H)+@M\'NVOXHKBD^**XI..@R!')"\"Y"8O`NA"AP:#RF+!UM6'E\N9
MS"AO`$`L"RX,WH/=@B9&*$<N""0.M8="@D*#)@J_@RP++@S>@]V")$8F1RX$
MZX\D">N:*$)"@D*#)@R&ARP*+@O>@]V")$8F1T*"0H,F"RX!?![MK^*(XI'B
MB.*1CH$O1P!`("\"["(O`O!"A@:!RF+!UM&&0H9"ARX.TH?1AB]``#@O00`\
M+`@N+P!`OX9"KP!$0J\`2"`)O8`O0`!(+"\`."XO`#P@+P!$WJ\`2-V`(D8D
M1RP"ZXXB"^N90J\`.$*O`#R"AB]!`#PL+P`X+B\`/"`)WHK=@")&)$="@$*!
M(@HL!7X>[Z[BC.*5XHSBE8R%*"\"]"HO`OA"AP:%RF+!UMF'+T0`1"]%`$A"
MKP`X0J\`/"](`#PH+P`X*B\`/"XO`$3:KP!(V8<@1")%*"\`0+V$0J\`.$*O
M`#RWA"]$`#PH+P`X*B\`/"X(VHG9AR9$*$4H"GH;ZJP@1"@`ZXPN"(B'*@KK
MC8J$*`S8A2X#>A[KK^**XI/BBN*3*@>*@R0O`OPF+P,`0H<&@\IBP=;5AR!"
M(D,D+P`P)B\`-"X(UHG5AR9"*$.1R)/)(F\`0"0()@DN"]:,U8<@0B)#+@:[
MAY?+F<PD"K^"*$(D""8)+@O6C-6'($(B0R8$=!ODJT*"A(,N!.N/)@>&@B1O
M`%Q"DM:))4,`!$*J``C8KP!D)40`#"0!=A[GJN*(XI'BB.*1(`*`@4*J`!#0
MKP!8)4``%$*J`!C:KP!L)44`'$*J`"#<KP!\)48`)"(O`P0@;P"`(!"P@68*
M3-]\_$_O`MQ.=6'___^MFDAX`'QA____K6A"D"%\9T4C`0`$0J@`""%\[\VK
MB0`,0J@`$"%\F+K<_@`40J@`&"%\$#)4=@`<0J@`("%\P]+A\``D0J@`*$*H
M`"Q"J``P0J@`-$*H`'A8CR`(3G5(YS\Z)F\`+"1O`#`H;P`T(&L`*")K`"PB
M#%O`2<`L`"X!WH?=AMZ'W8;>A]V&0H)"@R8'UHDL*P`P+BL`-"@(*@F:@YF"
M8P9"A5*'W84G0@`H)T,`+"@`YXPF`7H=ZJN&A"0`ZJH@`B(#TH?1AB=``#`G
M00`T("L`>&9<3>L`.'@_N(QL``"\2>S_P"8,[(LD`U*"[8K4BDAX`$`O"B\.
M8?___ZNZ1>H`0"\+8?___\MR3^\`$+2*9M[MBYG#+PPO`B\.8?___ZN6)TP`
M>$_O``Q,WUS\3G5T0)2`N<)M.$WK`#@O`B\*2'8(`&'___^K;B`"T*L`>"=`
M`'A/[P`,<D"R@&;,F<+5PB\+8?___\L26(]@`/]J)`Q-ZP`X+P(O"DAV"`!A
M____JS0@`M"K`'@G0`!X3^\`#')`LH!FDF#$)`HO#"\"+PYA____JQ`G3`!X
M3^\`#&``_WA(YSXX)F\`)"1O`"@D*@`H)BH`+"@J`#`J*@`T(`(B`^*(XI'B
MB.*1XHCBD7P_PH9)Z@`X(`%2@!F\_X`8`'(XLH!L``$>0?0(`')`DH!\!+R!
M8P`",G`"L(%C``(@2H%F``'N+PIA____REQ"G$*<0IQ"G$*<0IQ"G$*<0IQ"
MG$*<0IQ"G$*46(\@!7P8[*@50`!P(`0B!3($2$$500!Q(`0B!1($X)D500!R
M%44`<R`#[*@50`!T(`(B`S("2$$500!U(`(B`Q("X)D500!V%4,`=R\*8?__
M_\GL%JH`!!=J``4``1=J``8``A=J``<``Q=J``P`!!=J``T`!1=J``X`!A=J
M``\`!Q=J`!0`"!=J`!4`"1=J`!8`"A=J`!<`"Q=J`!P`#!=J`!T`#1=J`!X`
M#A=J`!\`#Q=J`"0`$!=J`"4`$1=J`"8`$A=J`"<`$UB/+TH`)$S?''Q@____
MJ-IR.)*`+P%"ITAT"`!A____J&1/[P`,(`5\&.RH%4``<"`$(@4R!$A!%4$`
M<2`$(@42!."9%4$`<A5%`',@`^RH%4``="`"(@,R`DA!%4$`=2`"(@,2`N"9
M%4$`=A5#`'<O"F'____(_A:J``07:@`%``$7:@`&``(7:@`'``,7:@`,``07
M:@`-``47:@`.``87:@`/``<7:@`4``@7:@`5``D7:@`6``H7:@`7``L7:@`<
M``P7:@`=``T7:@`>``X7:@`?``\7:@`D`!`7:@`E`!$7:@`F`!(7:@`G`!-8
MCR]*`"1,WQQ\8/___Z?L0A`O"F'____(;D*<0IQ"G$*<0IQ"G$*<0IQ"G$*<
M0IQ"G$*<0I18CV``_A!"6%6!9P#]XF#*0IA9@7`"L(%B`/W.8.@O#4O[`7``
M`&U0('4!<````1PO$"\O`!0O+P`4+R\`%&'___^FSD_O`!`J7TYU3G%.5@``
M+PU+^P%P``!M'"IN__Q.7DYU``(``25S+R5S`"]P<F]C+W-E;&8O97AE`$1Y
M;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/
M5``O<')O8R\E:2\E<P`N`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$52
M3#5,24(`4$523$Q)0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$
M`%!!4E]34$%73D5$`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!
M4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!0
M05)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@`Q`&QS965K(&9A:6QE
M9`!R96%D(&9A:6QE9`!,1%],24)205)97U!!5$@`4UE35$5-`"]T;7``5$5-
M4$1)4@!435``55-%4@!54T523D%-10`E,#)X`'!A<BT`)7,E<R5S)7,`)7,Z
M(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H
M97)R;F\])6DI"@`E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS
M869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO
M;BD*`'!A<FP`+G!A<@!S:&]R="!R96%D`"5S)7-C86-H92TE<R5S`"5S)7-T
M96UP+25U)7,`)7,E<W1E;7`M)74M)74E<P`8`'!E<FP`,`!005(Z.E!A8VME
M<CHZ5D524TE/3@`Q+C`V,P!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C
M=&]R>0`E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O
M<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*`"UE`"TM`&5V86P@)V5X96,@+W5S
M<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN
M:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"10
M05)?34%'24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D8V%C:&5?;F%M95]S:7IE
M*3L*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PHD1DE,15]O
M9F9S971?<VEZ92`](#0[("`@(R!P86-K*").(BD*)&-A8VAE7VYA;65?<VEZ
M92`](#0P.PHD4$M:25!?34%'24,@/2`B4$M<,#`S7#`P-"(["GT*<W5B(&9I
M;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I>F4@
M/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@+7,@)&9H.PIM>2`D
M<&]S(#T@*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@)&-H=6YK7W-I>F4[("`@
M("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I>F4*
M=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K("1F:"P@)'!O<RP@,#L*<F5A9"`D
M9F@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII
M9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P*2![
M"G)E='5R;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D8VAU;FM?<VEZ93L*?0IR
M971U<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL
M92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@
M>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64[
M"G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N
M86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL
M97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U
M8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M
M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU3
M5VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@
M/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE
M*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*
M;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB
M+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D
M<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A
M:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N
M86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM
M>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E
M;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T
M;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B![
M"DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS
M.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE
M="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@/2`H"G!A=&A?<V5P("`@
M(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@
M("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G
M(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_
M("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["F]U=',H<7%;7"1P
M<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?<&%R7W1E;7`H*3L*;W5T
M<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D["FUY
M("@D<W1A<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*3L*34%'24,Z
M('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E
M;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E
M860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H
M97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@
M)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA9VEC
M7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T<FEN9R`B
M)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#
M.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G:6-?
M<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I
M>F4@+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A9"!?1D@L("1B=68L(&QE
M;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!N92`B7#!#04-(12(@)B8@)&)U
M9B!N92`B7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C:&4@;6%R:V5R(&9O=6YD
M(BD["FQA<W0@34%'24,["GT*;W5T<RAQ<5M#86-H92!M87)K97(@(B1B=68B
M(&9O=6YD72D["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T
M7W-I>F4L(#`["G)E860@7T9(+"`D8G5F+"`D1DE,15]O9F9S971?<VEZ93L*
M;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I.PIO=71S*")/9F9S970@
M9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(+"`D
M;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2`D;V9F<V5T+"`P.PHD
M<W1A<G1?;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?1D@["FUY("5R97%U:7)E
M7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@
M("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q
M(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L
M('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S
M*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@
M/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@
M=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN
M*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(
M+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@
M86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE
M;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2
M.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B10
M05(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*
M?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D
M8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["B1R97%U
M:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]
M"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?
M.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O
M(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U<FX@=6YL97-S("1I;F9O
M.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D=6QE
M?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%
M04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)
M3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M
M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O
M+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E
M('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L
M("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA;64["F]P
M96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T
M(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O
M;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE
M(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ
M2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z
M.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I
M<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES
M("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65]
M(&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^
M("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O
M("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE
M7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*
M?0II9B`H)&)U9B!N92`D4$M:25!?34%'24,I('L*;W5T<RAQ<5M.;R!Z:7`@
M9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=
M*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T
M.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G
M<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID
M96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@
M;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S(&]R
M("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY
M("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?
M<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y
M7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@
M>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!
M4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D
M7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-
M3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*
M<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE
M=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`
M<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R
M.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE
M;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H
M)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@
M>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@
M;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A
M8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@
M)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI
M=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M
M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@
M9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN
M8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER
M92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A
M<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@
M>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@
M9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I
M;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&
M<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D
M<&%R(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@
M)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]
M?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A
M(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D
M<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#
M86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D
M("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL
M95T@=6YL97-S("1B=68@97$@)%!+6DE07TU!1TE#.PIC;&]S92`D<&@["GT*
M0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O
M=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]21%=2*"D@
M?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG
M="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E
M96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D<W1A<G1?
M;V9?1DE,15]S96-T:6]N*2!["G)E860@7T9(+"`D;&]A9&5R+"`D<W1A<G1?
M;V9?1DE,15]S96-T:6]N.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD
M;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD
M("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY
M*%PD;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D:64@
M<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O=70B.B`D(5T["FEF("@D
M8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H
M*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD
M;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL
M:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI
M.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E
M9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E
M9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG
M.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@;&EB7V5X="!V<R!D
M;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y
M<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF("AD969I;F5D*&UY
M("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL
M92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS92!["F9O<F5A8V@@;7D@
M)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI
M*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H
M)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E
M9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E
M9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D
M;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X="!U
M;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M97TK
M*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB
M7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N
M+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4I*3L*;7D@
M)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M
M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY("1T
M:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE
M(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ1FEL
M=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D
M;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<
M+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^
M;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*)&9H+3YP
M<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DL"G-P
M<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D
M8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI
M+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@96UB961D960@
M1DE,12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M
M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE
M*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R;W(@
M=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]"FEF("@D;65T85]P87)[
M8VQE86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%04XB*3L*?0IE;'-E('L*:68@
M*"%D969I;F5D("1C86-H95]N86UE*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(
M02T^;F5W*#$I.PIS965K("1F:"P@,"P@,#L*)&-T>"T^861D9FEL92@D9F@I
M.PIS965K("1F:"P@,"P@,CL*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E
M<W0["GT*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L("1C
M86-H95]N86UE7W-I>F4["B1C86-H95]N86UE("X](")<,"(@>"`H)&-A8VAE
M7VYA;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H
M)&-A8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*;7D@)&]F9G-E="`]("1F:"T^
M=&5L;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@
M)&]F9G-E="DL"B1005)?34%'24,I.PHD9F@M/F-L;W-E(&]R(&1I92!Q<5M%
M<G)O<B!W<FET:6YG('1R86EL97(@;V8@(B1O=70B.B`D(5T["F-H;6]D(#`W
M-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R
M=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0[
M"G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN
M97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII
M<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N
M;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A73L*
M07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]
M($%R8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE
M*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R
M(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B
M73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S
M:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N
M86UE?2`]("1Z:7`["F]U=',H(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF("AD
M969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T
M:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S
M("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R
M7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E
M<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R
M8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D
M,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM0
M05)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F
M)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S
M*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@
M97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X
M=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B+BXN72D[
M"B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D@/3T@
M07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@97AT<F%C
M=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE(ET["F-H;6]D*#`U-34L
M("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S
M("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL
M97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@
M6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@
M+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!
M345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R
M96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S
M96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A
M<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&
M:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M
M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U
M:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R
M.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A
M<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#
M87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ
M2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I
M<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A3
M3&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR
M97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U
M:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER
M92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0[
M"G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ
M1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A
M;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V
M86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!
M<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(
M87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R
M97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@
M?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%2
M7U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T
M96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D
M14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!4
M35`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@
M9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D
M=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I
M9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,
M;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*
M?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED
M.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6
M>U5315)]('Q\("=365-414TG.PI]"FUY("1S=&UP9&ER(#T@(B1P871H)'-Y
M<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER
M("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM005)?
M0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["GT*96QS92!["F]P
M96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T
M(')E860@(B1P<F]G;F%M92(Z("0A73L*:68@*"AM>2`D;6%G:6-?<&]S(#T@
M9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS965K("1F:"P@)&UA9VEC
M7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BDL
M(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B
M*3L*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`D;6%G:6-?
M<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*0HM
M("1C86-H95]N86UE7W-I>F4L(#`["G)E860@)&9H+"`D8G5F+"`D8V%C:&5?
M;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C86-H95]D:7(@/2`B8V%C
M:&4M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*:68@*"$D8V%C:&5?9&ER*2![
M"B1C86-H95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[4$%27T-,14%.?2`](#$[
M"GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C86-H95]D:7(B.PIM:V1I
M<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*
M;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@
M)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY
M("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE
M(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2![
M"FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO<&5N
M("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H<')I;G0@)&9H("1C;VYT
M96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@
M(B1T96UP;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D
M969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R
M('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B
M(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-
M17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N
M86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%
M35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P
M*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O
M9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!2
M3T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@
M,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R
M;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@
M>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C
M:"!M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0
M051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I
M<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]
M7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA
M;64D<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U]
M)'!R;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES
M>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D
M96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]
M("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H
M)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B
M+B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D
M("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97
M:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO
M;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L
M:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@
M/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[
M4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*
M)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$
M(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E
M("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.
M($1%0E5'("\I('L*)$5.5GLB4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/0D%,
M7R1?(GT@:68@97AI<W1S("1%3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II9B`H
M)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0I]
M"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP
M<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*
M?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G
M<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C
M:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N
M9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E
M<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2
M+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E
M;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I
M<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64[
M"D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI
M+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]
M"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<
M*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*
M7U]%3D1?7PH``$-!0TA%`'!E<FQX<VDN8P``````````!````!`````!1TY5
M```````````#`````@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````!YL```>*`````$`
M``,T`````0```T0````!```#3@````P``!80````#0``<'P````9``#<D```
M`!L````$````&@``W)0````<````!&___O4```&(````!0``"(0````&```"
M9`````H```39````"P```!`````5``````````,``-V@`````@```MP````4
M````!P```!<``!,T````!P``#N0````(```$4`````D````,````'@````AO
M___["````6____X```XD;____P````)O___P```-7F____D```!/````````
M````````````````````````````````````````````````W)@`````````
M````%E0``!9H```6?```%I```!:D```6N```%LP``!;@```6]```%P@``!<<
M```7,```%T0``!=8```7;```%X```!>4```7J```%[P``!?0```7Y```%_@`
M`!@,```8(```&#0``!A(```87```&'```!B$```8F```&*P``!C````8U```
M&.@``!C\```9$```&20``!DX```93```&6```!ET```9B```&9P``!FP```9
MQ```&=@``!GL```:````&A0``!HH```:/```&E```!ID```:>```&HP``!J@
M```:M```&L@``!K<```:\```&P0````````;$````````.`8````````````
M``````#@!```````````````````-0@``````````````````'"6``#@$@``
M`````.`<``!PG```<*L``'-H``!PQP``(\```+#F``!PIP``<-P``'#H``!P
MZ@``</,``'$```!Q`@``<@L``'$$``!Q#0``<14``'$>``!Q)0``<34``'%!
M``!Q2P``<54``'%?``!Q<```<8(``'&-``!QG0``<:X``'&P``!QO0``X`@`
M`'')``!QV0``<>```'%[``!QY0``<9@``''M``!Q\0``<?8``''_``!R!```
M<@D``'(2``!R30``<=0``'*@``!RI0``<JH``'*U``!RQ```<M(``'+C``!R
MY0``<NH``'+L``!S`0``<P<``',H``#@(```X"0``'#E``!S:0``<VP``.`H
M````````X!@``.`8````````X`0*4$%2+G!M"@````!S;P``1T-#.B`H1&5B
M:6%N(#$S+C,N,"TQ,BD@,3,N,RXP```N<VAS=')T86(`+FYO=&4N9VYU+F)U
M:6QD+6ED`"YI;G1E<G``+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU
M+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L=``N
M:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M90`N;F]T92Y!0DDM
M=&%G`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YG;W0`+F1A
M=&$`+F)S<P`N8V]M;65N=```````````````````````````````````````
M``````````````````````L````'`````@```50```%4````)```````````
M````!``````````>`````0````(```%X```!>`````T```````````````$`
M````````)F____8````"```!B````8@```#<````!``````````$````!```
M`#`````+`````@```F0```)D```&(`````4````"````!````!`````X````
M`P````(```B$```(A```!-D```````````````$`````````0&____\````"
M```-7@``#5X```#$````!``````````"`````@```$UO___^`````@``#B0`
M``XD````P`````4````"````!`````````!<````!`````(```[D```.Y```
M!%`````$``````````0````,````9@````0```!"```3-```$S0```+<````
M!````!0````$````#````'`````!````!@``%A```!80````)@``````````
M`````@````````!K`````0````8``!8X```6.```!-@```````````````0`
M```4````=@````$````&```;$```&Q```%5L```````````````$````````
M`'P````!````!@``<'P``'!\````%@```````````````@````````""````
M`0````(``'"2``!PD@``0%X```````````````(`````````B@````$````"
M``"P\```L/`````$```````````````"`````````)0````'`````@``L/0`
M`+#T````(```````````````!`````````"B````#@````,``-R0``"\D```
M``0```````````````(````$````K@````\````#``#<E```O)0````$````
M```````````"````!````+H````&`````P``W)@``+R8```!"`````4`````
M````!`````@```##`````0````,``-V@``"]H````F````````````````0`
M```$````R`````$````#``#@````P``````8```````````````$````````
M`,X````(`````P``X!@``,`8````%```````````````!`````````#3````
M`0```#````````#`&````!\```````````````$````!`````0````,`````
<````````P#<```#<```````````````!````````
